@@ -2,6 +2,7 @@ import sys
 import shutil
 
 from pathlib import Path
+from typing import Dict, List
 
 from moodle_dl.utils import cutie
 from moodle_dl.utils.logger import Log
@@ -179,7 +180,7 @@ class ConfigService:
 
         self.section_seperator()
 
-    def _select_courses_to_download(self, courses: [Course]):
+    def _select_courses_to_download(self, courses: List[Course]):
         """
         Asks the user for the courses that should be downloaded.
         @param courses: All available courses
@@ -241,7 +242,7 @@ class ConfigService:
             self.config_helper.set_property('dont_download_course_ids', course_ids)
             self.config_helper.remove_property('download_course_ids')
 
-    def _select_sections_to_download(self, sections: [{}], excluded: [int]) -> [int]:
+    def _select_sections_to_download(self, sections: List[Dict], excluded: List[int]) -> List[int]:
         """
         Asks the user for the sections that should be downloaded.
         @param sections: All available sections
@@ -269,7 +270,7 @@ class ConfigService:
 
         return dont_download_section_ids
 
-    def _set_options_of_courses(self, courses: [Course]):
+    def _set_options_of_courses(self, courses: List[Course]):
         """
         Let the user set special options for every single course
         """
@@ -340,7 +341,7 @@ class ConfigService:
                 sel = choices_courses[selected_course - 1]
                 self._change_settings_of(sel, options_of_courses)
 
-    def _change_settings_of(self, course: Course, options_of_courses: {}):
+    def _change_settings_of(self, course: Course, options_of_courses: Dict):
         """
         Ask for a new Name for the course.
         Then asks if a file structure should be created.
