@@ -2,6 +2,7 @@ import re
 import html
 import logging
 import hashlib
+from typing import Dict, List
 import urllib.parse as urlparse
 
 from moodle_dl.state_recorder.course import Course
@@ -28,7 +29,9 @@ class ResultsHandler:
         logging.debug('Detected moodle version: %d', version)
 
     @staticmethod
-    def should_download_course(course_id: int, download_course_ids: [int], dont_download_course_ids: [int]) -> bool:
+    def should_download_course(
+        course_id: int, download_course_ids: List[int], dont_download_course_ids: List[int]
+    ) -> bool:
         """
         Checks if a course is in White-list and not in Blacklist
         """
@@ -38,14 +41,14 @@ class ResultsHandler:
         return inWhitelist and not inBlacklist
 
     @staticmethod
-    def should_download_section(section_id: int, dont_download_sections_ids: [int]) -> bool:
+    def should_download_section(section_id: int, dont_download_sections_ids: List[int]) -> bool:
         """
         Checks if a section is not in Blacklist
         """
 
         return section_id not in dont_download_sections_ids or len(dont_download_sections_ids) == 0
 
-    def _get_files_in_sections(self, course_sections: []) -> [File]:
+    def _get_files_in_sections(self, course_sections: List) -> List[File]:
         """
         Iterates over all sections of a course to find files (or modules).
         @param course_sections: The course object returned by Moodle,
@@ -69,7 +72,7 @@ class ResultsHandler:
 
         return files
 
-    def _get_files_in_modules(self, section_name: str, section_id: int, section_modules: []) -> [File]:
+    def _get_files_in_modules(self, section_name: str, section_id: int, section_modules: List) -> List[File]:
         """
         Iterates over all modules to find files (or content) in them.
         @param section_name: The name of the section to be iterated over.
@@ -163,7 +166,7 @@ class ResultsHandler:
         else:
             return modname.capitalize()
 
-    def _get_files_not_on_main_page(self) -> [File]:
+    def _get_files_not_on_main_page(self) -> List[File]:
         """
         Iterates over all addons to find files (or content) that are not listed on the main page.
         @return: A list of files of addons not on the main pange.
@@ -253,8 +256,8 @@ class ResultsHandler:
         content_filepath: str,
         content_html: str,
         no_search_for_moodle_urls: bool,
-        filter_urls_containing: [str],
-    ) -> [File]:
+        filter_urls_containing: List[str],
+    ) -> List[File]:
         """Parses a html string to find all urls in it. Then it creates for every url a file entry.
 
         Args:
@@ -346,7 +349,7 @@ class ResultsHandler:
 
     def _handle_cookie_mod(
         self, section_name: str, section_id: int, module_name: str, module_modname: str, module_id: str, module_url: str
-    ) -> [File]:
+    ) -> List[File]:
         """
         Creates a list of files out of a cookie module
         @param module_url: The url to the cookie module.
@@ -380,8 +383,8 @@ class ResultsHandler:
         module_name: str,
         module_modname: str,
         module_id: str,
-        module_contents: [],
-    ) -> [File]:
+        module_contents: List,
+    ) -> List[File]:
         """
         Iterates over all files that are in a module or assignment and
         returns a list of all files
@@ -472,7 +475,7 @@ class ResultsHandler:
         module_modname: str,
         module_id: str,
         module_description: str,
-    ) -> [File]:
+    ) -> List[File]:
         """
         Creates a description file
         @param module_description: The description of the module
@@ -532,7 +535,7 @@ class ResultsHandler:
 
         return files
 
-    def set_fetch_addons(self, course_fetch_addons: {}):
+    def set_fetch_addons(self, course_fetch_addons: Dict):
         """
         Sets the optional data that will be added to the result list
          during the process.
@@ -541,7 +544,7 @@ class ResultsHandler:
         """
         self.course_fetch_addons = course_fetch_addons
 
-    def fetch_files(self, course: Course) -> [File]:
+    def fetch_files(self, course: Course) -> List[File]:
         """
         Queries the Moodle system for all the files that
         are present in a course
